@@ -9,7 +9,6 @@ from operator import itemgetter
 from typing import (
     TYPE_CHECKING,
     Any,
-    Callable,
 )
 
 import polars._reexport as pl
@@ -44,6 +43,7 @@ from polars._utils.various import (
 from polars.datatypes import (
     N_INFER_DEFAULT,
     Categorical,
+    Duration,
     Enum,
     String,
     Struct,
@@ -59,7 +59,7 @@ with contextlib.suppress(ImportError):  # Module not available when building doc
     from polars._plr import PyDataFrame
 
 if TYPE_CHECKING:
-    from collections.abc import Iterable, MutableMapping
+    from collections.abc import Callable, Iterable, MutableMapping
 
     from polars import DataFrame, Series
     from polars._plr import PySeries
@@ -131,6 +131,7 @@ def dict_to_pydf(
                                 ),
                                 list(data.items()),
                             ),
+                            strict=True,
                         )
                     )
             except FileNotFoundError:
@@ -324,7 +325,11 @@ def _post_apply_columns(
         elif structs and (struct := structs.get(col)) and struct != pydf_dtype:
             column_casts.append(F.col(col).cast(struct, strict=strict)._pyexpr)
         elif dtype is not None and dtype != Unknown and dtype != pydf_dtype:
-            column_casts.append(F.col(col).cast(dtype, strict=strict)._pyexpr)
+            if dtype.is_temporal() and dtype != Duration and pydf_dtype == String:
+                temporal_cast = F.col(col).str.strptime(dtype, strict=strict)._pyexpr  # type: ignore[arg-type]
+                column_casts.append(temporal_cast)
+            else:
+                column_casts.append(F.col(col).cast(dtype, strict=strict)._pyexpr)
 
     if column_casts or column_subset:
         pyldf = pydf.lazy()
@@ -721,13 +726,6 @@ def _sequence_of_dict_to_pydf(
         strict=strict,
         infer_schema_length=infer_schema_length,
     )
-
-    # TODO: we can remove this `schema_overrides` block completely
-    #  once https://github.com/pola-rs/polars/issues/11044 is fixed
-    if schema_overrides:
-        pydf = _post_apply_columns(
-            pydf, columns=column_names, schema_overrides=schema_overrides, strict=strict
-        )
     return pydf
 
 
@@ -954,7 +952,7 @@ def _establish_dataclass_or_model_schema(
             )
 
     if model_fields and len(model_fields) == len(overrides):
-        overrides = dict(zip(model_fields, overrides.values()))
+        overrides = dict(zip(model_fields, overrides.values(), strict=True))
 
     return unpack_nested, column_names, schema_overrides, overrides
 
@@ -1019,6 +1017,7 @@ def iterable_to_pydf(
             strict=strict,
             orient="row",
             infer_schema_length=infer_schema_length,
+            schema_overrides=schema_overrides,
         )
 
     n_chunks = 0
@@ -1162,9 +1161,8 @@ def _pandas_has_default_index(df: pd.DataFrame) -> bool:
     else:
         # finally, is the index _equivalent_ to a default unnamed
         # integer index with frame data that was previously sorted
-        return (
-            str(df.index.dtype).startswith("int")
-            and (df.index.sort_values() == np.arange(len(df))).all()
+        return str(df.index.dtype).startswith("int") and bool(
+            (df.index.sort_values() == np.arange(len(df))).all()
         )
 
 
@@ -1294,7 +1292,7 @@ def numpy_to_pydf(
                 strict=strict,
                 nan_to_null=nan_to_null,
             )._s
-            for series_name, record_name in zip(column_names, record_names)
+            for series_name, record_name in zip(column_names, record_names, strict=True)
         ]
     elif shape == (0,) and n_columns == 0:
         data_series = []
