@@ -1,6 +1,7 @@
 import os
 import sys
-from typing import Any, Callable
+from collections.abc import Callable
+from typing import Any
 
 
 def verbose() -> bool:
