@@ -20,7 +20,6 @@ from pathlib import Path
 from typing import (
     TYPE_CHECKING,
     Any,
-    Callable,
     Literal,
     TypeVar,
     overload,
@@ -28,6 +27,8 @@ from typing import (
 
 import polars as pl
 from polars import functions as F
+from polars._dependencies import _check_for_numpy, import_optional, subprocess
+from polars._dependencies import numpy as np
 from polars.datatypes import (
     Boolean,
     Date,
@@ -39,11 +40,15 @@ from polars.datatypes import (
     Time,
 )
 from polars.datatypes.group import FLOAT_DTYPES, INTEGER_DTYPES
-from polars.dependencies import _check_for_numpy, import_optional, subprocess
-from polars.dependencies import numpy as np
 
 if TYPE_CHECKING:
-    from collections.abc import Iterator, MutableMapping, Reversible
+    from collections.abc import (
+        Callable,
+        Iterator,
+        MutableMapping,
+        Reversible,
+    )
+    from typing import ParamSpec, TypeGuard
 
     from polars import DataFrame, Expr
     from polars._typing import PolarsDataType, SizeUnit
@@ -53,11 +58,6 @@ if TYPE_CHECKING:
     else:
         from typing_extensions import TypeIs
 
-    if sys.version_info >= (3, 10):
-        from typing import ParamSpec, TypeGuard
-    else:
-        from typing_extensions import ParamSpec, TypeGuard
-
     P = ParamSpec("P")
     T = TypeVar("T")
 
@@ -212,6 +212,15 @@ def _in_notebook() -> bool:
     return True
 
 
+def _in_marimo_notebook() -> bool:
+    try:
+        import marimo as mo
+
+        return mo.running_in_notebook()  # pragma: no cover
+    except ImportError:
+        return False
+
+
 def arrlen(obj: Any) -> int | None:
     """Return length of (non-string/dict) sequence; returns None for non-sequences."""
     try:
@@ -387,7 +396,7 @@ def _cast_repr_strings_with_schema(
                     .then(pl.when(F.col(c).str.len_bytes() > 0).then(F.col(c)))
                     # check for scientific notation
                     .when(F.col(c).str.contains("[eE]"))
-                    .then(F.col(c).str.replace(r"[^eE\d]", "."))
+                    .then(F.col(c).str.replace(r"[^eE\d+-]", "."))
                     .otherwise(
                         # recombine sanitised integer/fractional components
                         pl.concat_str(
@@ -578,7 +587,7 @@ def _polars_warn(msg: str, category: type[Warning] = UserWarning) -> None:
 
 
 def extend_bool(
-    value: bool | Sequence[bool],
+    value: bool | Sequence[bool],  # noqa: FBT001
     n_match: int,
     value_name: str,
     match_name: str,
@@ -665,7 +674,11 @@ def display_dot_graph(
         return dot
 
     output_type = (
-        "svg" if _in_notebook() or "POLARS_DOT_SVG_VIEWER" in os.environ else "png"
+        "svg"
+        if _in_notebook()
+        or _in_marimo_notebook()
+        or "POLARS_DOT_SVG_VIEWER" in os.environ
+        else "png"
     )
 
     try:
@@ -689,6 +702,10 @@ def display_dot_graph(
         from IPython.display import SVG, display
 
         return display(SVG(graph))
+    elif _in_marimo_notebook():
+        import marimo as mo
+
+        return mo.Html(f"{graph.decode()}")
     else:
         if (cmd := os.environ.get("POLARS_DOT_SVG_VIEWER", None)) is not None:
             import tempfile
