@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import contextlib
 import warnings
-from typing import TYPE_CHECKING, Any, Callable, overload
+from typing import TYPE_CHECKING, Any, overload
 
 import polars._reexport as pl
 import polars.functions as F
@@ -36,7 +36,7 @@ with contextlib.suppress(ImportError):  # Module not available when building doc
 
 if TYPE_CHECKING:
     import sys
-    from collections.abc import Awaitable, Collection, Iterable, Sequence
+    from collections.abc import Awaitable, Callable, Collection, Iterable, Sequence
     from typing import Literal
 
     from polars import DataFrame, Expr, LazyFrame, Series
@@ -154,7 +154,7 @@ def element() -> Expr:
     │ 3   ┆ 2   ┆ [2]       │
     └─────┴─────┴───────────┘
     """
-    return F.col("")
+    return wrap_expr(plr.element())
 
 
 def count(*columns: str) -> Expr:
@@ -1334,7 +1334,7 @@ def _row_encode(
     return wrap_expr(result)
 
 
-def _wrap_acc_lamba(
+def _wrap_acc_lambda(
     function: Callable[[Series, Series], Series],
 ) -> Callable[[tuple[plr.PySeries, plr.PySeries]], plr.PySeries]:
     def wrapper(t: tuple[plr.PySeries, plr.PySeries]) -> plr.PySeries:
@@ -1466,7 +1466,7 @@ def fold(
     return wrap_expr(
         plr.fold(
             pyacc,
-            _wrap_acc_lamba(function),
+            _wrap_acc_lambda(function),
             pyexprs,
             returns_scalar=returns_scalar,
             return_dtype=rt,
@@ -1549,7 +1549,7 @@ def reduce(
     pyexprs = parse_into_list_of_expressions(exprs)
     return wrap_expr(
         plr.reduce(
-            _wrap_acc_lamba(function),
+            _wrap_acc_lambda(function),
             pyexprs,
             returns_scalar=returns_scalar,
             return_dtype=rt,
@@ -1631,7 +1631,7 @@ def cum_fold(
     return wrap_expr(
         plr.cum_fold(
             pyacc,
-            _wrap_acc_lamba(function),
+            _wrap_acc_lambda(function),
             pyexprs,
             returns_scalar=returns_scalar,
             return_dtype=rt,
@@ -1699,7 +1699,7 @@ def cum_reduce(
     pyexprs = parse_into_list_of_expressions(exprs)
     return wrap_expr(
         plr.cum_reduce(
-            _wrap_acc_lamba(function),
+            _wrap_acc_lambda(function),
             pyexprs,
             returns_scalar=returns_scalar,
             return_dtype=rt,
@@ -2009,6 +2009,46 @@ def arg_sort_by(
     )
 
 
+@overload
+def collect_all(
+    lazy_frames: Iterable[LazyFrame],
+    *,
+    type_coercion: bool = True,
+    predicate_pushdown: bool = True,
+    projection_pushdown: bool = True,
+    simplify_expression: bool = True,
+    no_optimization: bool = False,
+    slice_pushdown: bool = True,
+    comm_subplan_elim: bool = True,
+    comm_subexpr_elim: bool = True,
+    cluster_with_columns: bool = True,
+    collapse_joins: bool = True,
+    optimizations: QueryOptFlags = DEFAULT_QUERY_OPT_FLAGS,
+    engine: EngineType = "auto",
+    lazy: Literal[False] = False,
+) -> list[DataFrame]: ...
+
+
+@overload
+def collect_all(
+    lazy_frames: Iterable[LazyFrame],
+    *,
+    type_coercion: bool = True,
+    predicate_pushdown: bool = True,
+    projection_pushdown: bool = True,
+    simplify_expression: bool = True,
+    no_optimization: bool = False,
+    slice_pushdown: bool = True,
+    comm_subplan_elim: bool = True,
+    comm_subexpr_elim: bool = True,
+    cluster_with_columns: bool = True,
+    collapse_joins: bool = True,
+    optimizations: QueryOptFlags = DEFAULT_QUERY_OPT_FLAGS,
+    engine: EngineType = "auto",
+    lazy: Literal[True],
+) -> LazyFrame: ...
+
+
 @deprecate_streaming_parameter()
 @forward_old_opt_flags()
 def collect_all(
@@ -2026,7 +2066,8 @@ def collect_all(
     collapse_joins: bool = True,
     optimizations: QueryOptFlags = DEFAULT_QUERY_OPT_FLAGS,
     engine: EngineType = "auto",
-) -> list[DataFrame]:
+    lazy: bool = False,
+) -> list[DataFrame] | LazyFrame:
     """
     Collect multiple LazyFrames at the same time.
 
@@ -2107,6 +2148,13 @@ def collect_all(
         .. note::
            The GPU engine does not support async, or running in the
            background. If either are enabled, then GPU execution is switched off.
+    lazy:
+        Return as LazyFrame that can be collected later.
+        This is only correct if all inputs sink to disk.
+
+        .. warning::
+            This functionality is considered **unstable**. It may be changed
+            at any point without it being considered a breaking change.
 
     Returns
     -------
@@ -2114,10 +2162,17 @@ def collect_all(
         The collected DataFrames, returned in the same order as the input LazyFrames.
 
     """
-    if engine == "streaming":
-        issue_unstable_warning("streaming mode is considered unstable.")
-
     lfs = [lf._ldf for lf in lazy_frames]
+    if lazy:
+        msg = "the `lazy` parameter of `collect_all` is considered unstable."
+        issue_unstable_warning(msg)
+
+        from polars.lazyframe import LazyFrame
+
+        ldf = plr.collect_all_lazy(lfs, optimizations._pyoptflags)
+        lf = LazyFrame._from_pyldf(ldf)
+        return lf
+
     out = plr.collect_all(lfs, engine, optimizations._pyoptflags)
 
     # wrap the pydataframes into dataframe
