@@ -456,6 +456,12 @@ class ConnectionExecutor:
         """Execute a query using an async SQLAlchemy connection."""
         is_session = self._is_alchemy_session(self.cursor)
         cursor = self.cursor.begin() if is_session else self.cursor  # type: ignore[attr-defined]
+
+        # check if connection is already started (eg: user awaited `engine.connect()`);
+        # if so, use it directly without entering the context manager again
+        if getattr(cursor, "sync_connection", None) is not None:
+            return await cursor.execute(query, **options)
+
         async with cursor as conn:  # type: ignore[union-attr]
             if is_session and not hasattr(conn, "execute"):
                 conn = conn.session
