@@ -18,8 +18,7 @@ if TYPE_CHECKING:
 from dataclasses import dataclass
 
 
-# TODO: Add `kw_only=True` after 3.9 support dropped
-@dataclass
+@dataclass(kw_only=True)
 class ScanOptions:
     """
     Holds scan options that are generic over scan type.
